test_reports = {
    100: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "PASSED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    },
    101: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "PASSED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    },
    102: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "PASSED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    },
    103: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "PASSED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    },
    104: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "PASSED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "FAILED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    },
    105: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "FAILED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "FAILED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    },
    106: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "PASSED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    },
    107: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "FAILED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "FAILED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "FAILED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 39000
                        }
                    ]
                }
            ]
        }
    },
    108: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "FAILED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "PASSED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    },
    109: {
        'duration':
            200000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "FAILED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 30000
                        },
                        {
                            "status": "PASSED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 70000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Browser Public Commodity",
                            "duration": 60000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    },
    110: {
        'duration':
            210000,
        'report': {
            'suites': [
                {
                    "name": "Login Wepage",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Loging with Correct Username and Password",
                            "duration": 20000
                        },
                        {
                            "status": "PASSED",
                            "name": "Loging with Incorrect Username and Password",
                            "duration": 60000
                        }
                    ]
                },
                {
                    "name": "Browser Commodity",
                    "cases": [
                        {
                            "status": "PASSED",
                            "name": "Browser Public Commodity",
                            "duration": 57000
                        },
                        {
                            "status": "PASSED",
                            "name": "Browser Private Commodity",
                            "duration": 40000
                        }
                    ]
                }
            ]
        }
    }
}
